@@ -4,8 +4,8 @@
 # ><>< ================================================================ ><>< #
 
 # ><>< # "hbParameters" Object Generics and Methods
-setClass("hbParameters", representation(psize="numeric", vNvS="numeric",
-    sampler="numeric", nsynVar="numeric", words="character"))
+setClass("hbParameters", representation(psize="numeric",
+    vNvS="numeric", sampler="numeric", nsynVar="numeric", words="character"))
 
 setMethod("show", "hbParameters", function(object){
     cat("\n", is(object)[[1]])
